diff --git a/dumux/common/timeloop.hh b/dumux/common/timeloop.hh
index 3f2e02dad9c74e1c8d7d30cb3dbc1ef7e02e4c0c..80bd80b3d5999ae91daa8a56b0e4ed8dc1fe7fff 100644
--- a/dumux/common/timeloop.hh
+++ b/dumux/common/timeloop.hh
@@ -166,9 +166,9 @@ public:
     { endTime_ = t; }
 
     /*!
      * \brief Returns the current wall time (cpu time).
      */
-    double wallTime() const
+    double wallClockTime() const
     {  return cpuTime_; }
 
     /*!
@@ -166,9 +166,9 @@ public:
 
     /*!
-     * \brief Returns the current wall time (cpu time).
+     * \brief Returns the current wall clock time (cpu time).
      */